=================
MU Environment
=================

About
==============

Entry point into Self Describing Environment (SDE). Sets up and parses state of workspace before calling into build.

Version History
===============

0.2.1
-----

Fixing error in UefiBuild where spaces weren't placed between parameters

0.2.0
-----

Initial commit